@@ -52,7 +52,7 @@
   (defun-maybe Meadow-version ()))
 
 (product-provide 'weather-version
-  (product-define "Weather" nil '(0 31)))
+  (product-define "Weather" nil '(0 32)))
 
 (defvar weather-insert-user-agent nil)
 
@@ -305,9 +305,9 @@
 				  (string-to-int (match-string 2)))
 			  (error "Weather: $BH/I=;~4V$r8+IU$1$i$l$^$;$s!%(B")))
 		  (while (re-search-forward
-			  "<TH VALIGN=TOP ALIGN=LEFT>\\([^<]+\\)</TH>" nil t)
+			  "<TH VALIGN=\"?TOP\"? ALIGN=\"?LEFT\"?>\\([^<]+\\)</TH>" nil t)
 		    (setq ret-val (match-string 1))
-		    (search-forward "<TH VALIGN=TOP ALIGN=CENTER>" nil t)
+		    (re-search-forward "<TH VALIGN=\"?TOP\"? ALIGN=\"?CENTER\"?>" nil t)
 		    (re-search-forward "\\(<FONT COLOR=[^>]*>\\)?\\([^<]*\\)"
 				       nil t)
 		    (weather-set-cache ret-val date
